Origin-path-decl block per spec 3.4.
Block format:
- shared mode (bit 4 = 0):
[n: 5 bits, encoded n-1][origin-path-encoding] - divergent mode (bit 4 = 1):
[n: 5 bits, encoded n-1][origin-path-encoding × n]
origin-path-encoding (explicit-only per D19′):
[depth: 4 bits][component × depth]
component:
[hardened: 1 bit][value: LP4-ext varint]
Structs
- Origin
Path - An explicit BIP-32 origin path (a sequence of
PathComponents). - Path
Component - A single BIP-32 path component (e.g.
84'or0). - Path
Decl - A path declaration: key count
nplus either a shared origin path orndivergent origin paths (mode selected by header bit 4).
Enums
- Path
Decl Paths - Path payload for a
PathDecl.
Constants
- MAX_
PATH_ COMPONENTS - Maximum number of components in a single origin path (4-bit depth field).